==> gnuradio_3.6.5.1.orig.tar.gz: gnuradio-3.6.5.1/gr-blocks/lib/vco_f_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2005,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_GR_VCO_F_IMPL_H
#define INCLUDED_GR_VCO_F_IMPL_H

#include <blocks/vco_f.h>
#include <gr_fxpt_vco.h>

namespace gr {
  namespace blocks {

    class vco_f_impl : public vco_f
    {
    private:
      double d_sampling_rate;
      double d_sensitivity;
      double d_amplitude;
      double d_k;
      gr_fxpt_vco d_vco;

    public:
      vco_f_impl(double sampling_rate, double sensitivity, double amplitude);
      ~vco_f_impl();

      int work(int noutput_items,
               gr_vector_const_void_star &input_items,
               gr_vector_void_star &output_items);
    };

  } /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_GR_VCO_F_H */

==> gnuradio_3.7.11.orig.tar.gz: gnuradio-3.7.11/gr-blocks/lib/vco_f_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2005,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_GR_VCO_F_IMPL_H
#define INCLUDED_GR_VCO_F_IMPL_H

#include <gnuradio/blocks/vco_f.h>
#include <gnuradio/fxpt_vco.h>

namespace gr {
  namespace blocks {

    class vco_f_impl : public vco_f
    {
    private:
      double d_sampling_rate;
      double d_sensitivity;
      double d_amplitude;
      double d_k;
      gr::fxpt_vco d_vco;

    public:
      vco_f_impl(double sampling_rate, double sensitivity, double amplitude);
      ~vco_f_impl();

      int work(int noutput_items,
               gr_vector_const_void_star &input_items,
               gr_vector_void_star &output_items);
    };

  } /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_GR_VCO_F_H */
